/*
 * Library interface to Linux x86 Performance-Monitoring Counters.
 *
 * Copyright (C) 1999  Mikael Pettersson
 */

#ifndef __LIB_PERFCTR_H
#define __LIB_PERFCTR_H

#include "asm/perfctr.h"

/*
 * Invokes the kernel driver directly.
 */

extern int perfctr_syscall(unsigned cmd, long arg);

/*
 * Operations on explicitly attached perfctrs.
 */

struct perfctr;	/* opaque; users only see pointer to these */

extern struct perfctr *perfctr_attach_rdonly(int pid);
extern struct perfctr *perfctr_attach_rdwr(int pid, struct perfctr_control*);
extern int perfctr_read(const struct perfctr*, struct perfctr_state*);
extern int perfctr_control(const struct perfctr*, struct perfctr_control*);
extern int perfctr_stop(const struct perfctr*);
extern int perfctr_unlink(const struct perfctr*);
extern void perfctr_close(struct perfctr*);

/*
 * Operations on the process' own perfctrs.
 */

extern int perfctr_attach_rdonly_self(void);
extern int perfctr_attach_rdwr_self(void);
extern int perfctr_read_self(struct perfctr_state*);
extern int perfctr_control_self(struct perfctr_control*);
extern int perfctr_stop_self(void);
extern int perfctr_unlink_self(void);
extern void perfctr_close_self(void);

/*
 * Miscellaneous operations.
 */

extern int perfctr_info(struct perfctr_info*);
extern const char *perfctr_cpu_name(void);
extern unsigned perfctr_evntsel_num_insns(void);

#endif /* __LIB_PERFCTR_H */
